import seaborn as sns
import matplotlib.pyplot as plt

def swarm(data,x,y,xscale='linear',yscale='linear'):
    
    # set default pretty settings from Seaborn
    
    sns.set(style="white", palette="muted")
    sns.set_context("notebook", font_scale=1, rc={"lines.linewidth": 0.2}) 

    # createthe plot
    
    g = sns.swarmplot(x=x, y=y, data=data, palette='RdYlGn')
    
    plt.tick_params(axis='both', which='major', pad=10)

    g.set(xscale=xscale)
    g.set(yscale=yscale)

    # Setting plot limits
    
    start = data[y].min().min()
    plt.ylim(start,);
    
    sns.despine()


import pandas as pd

from IPython.core.display import display, HTML

def text(data,column,title='',rows=6, sort_by='',contains=''):
    
    if sort_by != '':
        data = data.sort_values(sort_by)
    
    data = data[column]
    
    if len(data) < rows:
        rows = len(data)

    display(HTML("<h3>"+ str(title) +"</h3>"))

    for i in range(rows):

        html = display(HTML("<font size=2 face=Helvetica>"+ str(pd.DataFrame(data[data.str.contains(contains)].value_counts()).index[i]) + "</font>"))

    return html


import warnings
from IPython.display import HTML

def toggle():

    html = HTML('''<script>
    code_show=true; 
    function code_toggle() {
     if (code_show){
     $('div.input').hide();
     } else {
     $('div.input').show();
     }
     code_show = !code_show
    } 
    $( document ).ready(code_toggle);
    </script>
    <a href="javascript:code_toggle()">toggle code cells</a>''')
    return html

def warning():
    
    warnings.filterwarnings('ignore')


import seaborn as sns
import matplotlib.pyplot as plt

def kde(x,y,title='',color='YlGnBu',xscale='linear',yscale='linear'):
    
    sns.set_style('white')
    sns.set_context('notebook', font_scale=1, rc={"lines.linewidth": 0.5})
    g = sns.kdeplot(x,y,shade=True, cut=2, cmap=color, shade_lowest=False, legend=True, set_title="test")
    plt.tick_params(axis='both', which='major', pad=10)
    sns.plt.title(title)
    
    g.set(xscale=xscale)
    g.set(yscale=yscale)
    
    sns.despine()


import pandas as pd

def prep(data,columns=''):
    
    """
      Data processor for desc_table() function.
      
      You can call it separately as well and in 
      return get a non-prettyfied summary table. 
      
      Unless columns are defined, the three first 
      columns are chosen by default. 
      
      SYNTAX EXAMPLE: 
      
      df['quality_score','influence_score','reach_score']
    
    """
       
    if data.shape[1] != 3:
        if len(columns) !=3:
            if data.shape[1] > 3:
                
                print "showing first three columns because no columns were specific / data had more than 3 columns"
                data = pd.DataFrame(data[data.columns[0:3]])
    
    if data.shape[1] < 3:
        
        print "You need at least 3 columns of data for this table"
        quit()
        
    if len(columns) == 3:
            data = data[columns]
            
    desc = pd.DataFrame({'sum' : data.sum().astype('int'),
                         'median' : data.median(),
                         'mean' : data.mean(),
                         'std' : data.std()})
    desc = desc.round(decimals=2)      
    
    return desc



import numpy as np
import seaborn as sns
import matplotlib.pyplot as plt

from matplotlib.pyplot import rcParams


def correlation(data,title=''):
    
    corr = data.corr(method='spearman')
    mask = np.zeros_like(corr)
    mask[np.triu_indices_from(mask)] = True

    sns.set(style="white")
    sns.set_context("notebook", font_scale=2, rc={"lines.linewidth": 0.3})
    
    rcParams['figure.figsize'] = 25, 12
    rcParams['font.family'] = 'Verdana'
    rcParams['figure.dpi'] = 300

    g = sns.heatmap(corr, mask=mask, linewidths=1, cmap="RdYlGn", annot=False)
    g.set_xticklabels(data,rotation=25,ha="right");
    plt.tick_params(axis='both', which='major', pad=15);


from bars import *
from bubble import *
from correlation import *
from data import *
from descriptive import *
from gui import *
from histogram import *
from kde import *
from ols import *
from regression import *
from swarm import *
from table import *
from text import *

__version__ = "0.9"


import pandas as pd
from IPython.core.display import display, HTML

def table(data,title="Descriptive Stats",table_title=""):
    
    """
      Takes in 3 features/columns of data, and
      returns a prettified publication quality 
      descriptive stats summary table. 
      
      The default column setting is for scores. 

      data = a pandas DataFrame
      columns = the columns inside [] and comma (,) separated 
                
                OPTIONS: 'score', 'user', 'polarity' or create
                one yourself using syntax like so: 
                
                df['quality_score','influence_score','reach_score']
                
    """

    from IPython.core.display import display, HTML
    display(HTML("<style type=\"text/css\"> .tg {border-collapse:collapse;border-spacing:0;border:none;} .tg td{font-family:Arial, sans-serif;font-size:14px;padding:10px 5px;border-style:solid;border-width:0px;overflow:hidden;word-break:normal;} .tg th{font-family:Arial, sans-serif;font-size:14px;font-weight:normal;padding:10px 5px;border-style:solid;border-width:0px;overflow:hidden;word-break:normal;} .tg .tg-ejgj{font-family:Verdana, Geneva, sans-serif !important;;vertical-align:top} .tg .tg-anay{font-family:Verdana, Geneva, sans-serif !important;;text-align:right;vertical-align:top} .tg .tg-jua3{font-weight:bold;font-family:Verdana, Geneva, sans-serif !important;;text-align:right;vertical-align:top} h5{font-family:Verdana;} h4{font-family:Verdana;} hr{height: 3px; background-color: #333;} .hr2{height: 1px; background-color: #333;} </style> <table class=\"tg\" style=\"undefined;table-layout: fixed; width: 500px; border-style: hidden; border-collapse: collapse;\"> <colgroup> <col style=\"width: 150px\"> <col style=\"width: 120px\"> <col style=\"width: 120px\"> <col style=\"width: 120px\"> <col style=\"width: 120px\"> </colgroup> <h5>" + str(table_title) + "</h5> <h4><i>" + str(title) + "</i></h4> <hr align=\"left\", width=\"630\"> <tr> <th class=\"tg-ejgj\"></th> <th class=\"tg-anay\">median</th> <th class=\"tg-anay\">mean</th> <th class=\"tg-anay\">std</th> <th class=\"tg-anay\">total</th> </tr> <tr> <td class=\"tg-ejgj\">" + data.index[0] + "</td> <td class=\"tg-jua3\">" + str(data['median'][0]) + "</td> <td class=\"tg-jua3\">" + str(data['mean'][0]) + "</td> <td class=\"tg-jua3\">" + str(data['std'][0]) + "</td> <td class=\"tg-jua3\">" + str(data['sum'][0]) + "</td> </tr> <tr> <td class=\"tg-ejgj\">" + data.index[1] + "</td> <td class=\"tg-jua3\">" + str(data['median'][1]) + "</td> <td class=\"tg-jua3\">" + str(data['mean'][1]) + "</td> <td class=\"tg-jua3\">" + str(data['std'][1]) + "</td> <td class=\"tg-jua3\">" + str(data['sum'][1]) + "</td> </tr> <tr> <td class=\"tg-ejgj\">" + data.index[2] + "</td> <td class=\"tg-jua3\">" + str(data['median'][2]) + "</td> <td class=\"tg-jua3\">" + str(data['mean'][2]) + "</td> <td class=\"tg-jua3\">" + str(data['std'][2]) + "</td> <td class=\"tg-jua3\">" + str(data['sum'][2]) + "</td> </tr> </table> <hr align=\"left\", width=\"630\">"))




import pandas as pd
import seaborn as sns
import matplotlib.pyplot as plt

def bars(data,color='black',title=''):

    data = pd.DataFrame(data.value_counts())
    data = data.reset_index()
    data.columns = ['keyword','value']
    data['keyword'] = data['keyword'][1:]
    data = data.dropna()
    data = data.reset_index(drop=True)
    data = data.sort_values('value',ascending=False)

    sns.set_context("notebook", font_scale=1.2, rc={"lines.linewidth": 0})

    x = data.head(20)['keyword'].astype(str)
    y = data.head(20)['value'].astype(int)

    f, ax = plt.subplots(figsize=(16, 3))

    sns.set_style('white')

    ## change color of the bar based on value

    colors = [color if _y >=0 else 'red' for _y in y]

    sns.barplot(x, y, palette=colors, ax=ax)
    
    plt.title(title, fontsize=18, y=1.12, color="gray");
    
    ax.set_xticklabels('')
    ax.set_ylabel('')
    ax.set_xlabel('')
    ax.tick_params(axis='both', which='major', pad=30)

    for n, (label, _y) in enumerate(zip(x, y)):
        ax.annotate(
            s='{:.1f}'.format(abs(_y)),
            xy=(n, _y),
            ha='center',va='center',
            xytext=(0,-10),
            size=12,
            textcoords='offset points',
            color="white",
            weight="bold"
        )
    ax.set_yticklabels("");
    ax.set_xticklabels(data.head(20)['keyword'],rotation=25,ha="right");
    ax.tick_params(axis='both', which='major', pad=15)
    sns.despine(left=True)


import seaborn as sns
import matplotlib.pyplot as plt

def regression(data,x,y,xscale='linear',yscale='linear'):


    sns.set_context("notebook", font_scale=.8, rc={"lines.linewidth": 0})
    sns.set_style('white')

    g = sns.regplot(x=x, y=y, data=data)
    
    plt.tick_params(axis='both', which='major', pad=10)

    g.set(xscale=xscale)
    g.set(yscale=yscale)

    sns.despine()


import pandas as pd
import statsmodels.api as sm
from patsy import dmatrices
from IPython.core.display import display, HTML

def ols(data,iv,dv1,dv2,dv3,title='OLS Summary',table_title=''):
    
    if len(table_title) == 0:
        
        table_title = "Independent Variable : " + str(iv)
    
    features = str(iv + ' ~ ' + dv1 + ' + ' + dv2 + ' + ' + dv3)
    y, X = dmatrices(features, data=data, return_type='dataframe')
    mod = sm.OLS(y, X)
    res = mod.fit()
    result = pd.DataFrame.transpose(pd.DataFrame([res.params,res.tvalues,res.pvalues,res.bse]))
    result.columns = ['coef','t','p_t','std_error']
    
    data = result.round(decimals=4)
    
    html = display(HTML("<style type=\"text/css\"> .tg {border-collapse:collapse;border-spacing:0;border:none;} .tg td{font-family:Arial, sans-serif;font-size:14px;padding:10px 5px;border-style:solid;border-width:0px;overflow:hidden;word-break:normal;} .tg th{font-family:Arial, sans-serif;font-size:14px;font-weight:normal;padding:10px 5px;border-style:solid;border-width:0px;overflow:hidden;word-break:normal;} .tg .tg-ejgj{font-family:Verdana, Geneva, sans-serif !important;;vertical-align:top} .tg .tg-anay{font-family:Verdana, Geneva, sans-serif !important;;text-align:right;vertical-align:top} .tg .tg-jua3{font-weight:bold;font-family:Verdana, Geneva, sans-serif !important;;text-align:right;vertical-align:top} h5{font-family:Verdana;} h4{font-family:Verdana;} hr{height: 3px; background-color: #333;} .hr2{height: 1px; background-color: #333;} </style> <table class=\"tg\" style=\"undefined;table-layout: fixed; width: 500px; border-style: hidden; border-collapse: collapse;\"> <colgroup> <col style=\"width: 150px\"> <col style=\"width: 120px\"> <col style=\"width: 120px\"> <col style=\"width: 120px\"> <col style=\"width: 120px\"> </colgroup> <h5>" + str(table_title) + "</h5> <h4><i>" + str(title) + "</i></h4> <hr align=\"left\", width=\"630\"> <tr> <th class=\"tg-ejgj\"></th> <th class=\"tg-anay\">" + str(data.keys()[0]) + "</th> <th class=\"tg-anay\">" + str(data.keys()[1]) + "</th> <th class=\"tg-anay\">" + str(data.keys()[2]) + "</th> <th class=\"tg-anay\">" + str(data.keys()[3]) + "</th> </tr> <tr> <td class=\"tg-ejgj\">" + str(data.index[0]) + "</td> <td class=\"tg-jua3\">" + str(data[data.keys()[0]][0]) + "</td> <td class=\"tg-jua3\">" + str(data[data.keys()[1]][0]) + "</td> <td class=\"tg-jua3\">" + str(data[data.keys()[2]][0]) + "</td> <td class=\"tg-jua3\">" + str(data[data.keys()[3]][0]) + "</td> </tr> <tr> <td class=\"tg-ejgj\">" + str(data.index[1]) + "</td> <td class=\"tg-jua3\">" + str(data[data.keys()[0]][1]) + "</td> <td class=\"tg-jua3\">" + str(data[data.keys()[1]][1]) + "</td> <td class=\"tg-jua3\">" + str(data[data.keys()[2]][1]) + "</td> <td class=\"tg-jua3\">" + str(data[data.keys()[3]][1]) + "</td> </tr> <tr> <td class=\"tg-ejgj\">" + str(data.index[2]) + "</td> <td class=\"tg-jua3\">" + str(data[data.keys()[0]][2]) + "</td> <td class=\"tg-jua3\">" + str(data[data.keys()[1]][2]) + "</td> <td class=\"tg-jua3\">" + str(data[data.keys()[2]][2]) + "</td> <td class=\"tg-jua3\">" + str(data[data.keys()[3]][2]) + "</td> </tr> <tr> <td class=\"tg-ejgj\">" + str(data.index[3]) + "</td> <td class=\"tg-jua3\">" + str(data[data.keys()[0]][3]) + "</td> <td class=\"tg-jua3\">" + str(data[data.keys()[1]][3]) + "</td> <td class=\"tg-jua3\">" + str(data[data.keys()[2]][3]) + "</td> <td class=\"tg-jua3\">" + str(data[data.keys()[3]][3]) + "</td> </tr>"))
    
    return html


import matplotlib.pylab as plt
import seaborn as sns
import numpy as np

def histogram(data,variables):
    
    sns.set_context("notebook", font_scale=1.5, rc={"lines.linewidth": 0})

    sns.set_style('white')

    var_length = len(variables)
    
    fig, axes = plt.subplots(1, var_length, figsize=(19, 5))
    
    for i in range(var_length):
        
        axes[i].hist(data[variables[i]],lw=0,color="indianred",bins=8);
        axes[i].tick_params(axis='both', which='major', pad=15)
        axes[i].set_xlabel(variables[i])
        axes[i].set_yticklabels("");
    
    sns.despine(left=True)
    


import seaborn as sns
import matplotlib.pyplot as plt

def bubble(data,x,y,hue,bsize,palette='Reds',xscale='linear',yscale='linear',title='',suptitle=0):
    
    if suptitle == 0:
        suptitle = bsize
    
    sns.set(style="whitegrid")
    sns.set_context("notebook", font_scale=3, rc={"lines.linewidth": 0.3})

    sns.set_color_codes("bright")

    size = (1500 / float(data[bsize].max()))
    size = data[bsize] * size

    g = sns.PairGrid(data, hue=hue, palette=palette, y_vars=y, x_vars=x, size=12, aspect=3)
    
    g.map(plt.scatter, s=size);
    
    g.set(xscale=xscale)
    g.set(yscale=yscale)
    
    g.add_legend(title=hue, bbox_to_anchor=(0.9, 0.6))

    plt.title(title, fontsize=48, y=1.12, color="gray");
    
    plt.suptitle("size = " + suptitle, verticalalignment='top', fontsize=35, y=1.01, x=0.48, color="gray")
    plt.xlabel(x, fontsize=38, labelpad=30, color="gray");
    plt.ylabel(y, fontsize=38, labelpad=30, color="gray");

    plt.tick_params(axis='both', which='major', pad=25)

    plt.axhline(linewidth=2.5, color="black");
    plt.axvline(linewidth=2.5, color="black");
    plt.ylim(0,);
    plt.xlim(0,);


import pandas as pd

from prep import prep
from table import table

def descriptive(data,columns='',title="Descriptive Stats",table_title=""):
    
    """
    
    Example use: 
        
        descriptive(df,['neg','neu','pos'],"This is the Title")
    
    """
    
    if columns == '':
        
        table(prep(data),title=title,table_title=table_title)
        
    else:
        
        table(prep(data[columns]),title=title,table_title=table_title)